==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Preglednik slika</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovne informacije</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Pojedinosti</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Otvori direktorij</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemate dozvolu da pogledate sliku</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slikovna datoteka nije nađena</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Nadnevak izmjene</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimenzija</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Veličina mape</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Način ekspozicije</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozicije</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Vrijeme ekspozicije</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Bljeskalica</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Žarišna daljina</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balans bijele boje</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model leća</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Područje boja</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetri</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centrimetri</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inči</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Pozicija slike</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Postavke slike</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Postavke slike</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Unesi novo ime</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Odaberi direktorij</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Dodaj mapu</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Upravljanje sinkoronizacijom direktorija</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Lista direktorija je prazna</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Otkaži sinkronizaciju</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Uređaj je uklonjen</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktorij više ne postoji</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Računam...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pregledavanje slika</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Kraj prikaza</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ukloni iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacija o slici</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Prethodni zaslon</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Slijedeći zaslon</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novi album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži prečace</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Napusti cijeli zaslon</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Molim unesite novi prečac</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Prečaci</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Pogledaj sliku</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Vratite na zadano</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Kraj prikaza</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ukloni iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacija o slici</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novi album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauziraj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch effect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>second</source>
        <translation>sekunda</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 veličina</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pristaje u prozor</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Upravljanje slikama</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moj omiljeni</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 veličina</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pristaje u prozor</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>NIje pronađena nijedna slikovna datoteka</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slikovna datoteka nije nađena</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Prečaci</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Novi album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Vremenski okvir</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj u album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj u novi album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Napusti cijeli zaslon</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ukloni iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijski prozor</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sakrij navigacijski prozor</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacija o slici</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Sve slike</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.3.orig.tar.xz: deepin-image-viewer-5.9.3/src/translations/deepin-image-viewer_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Slikovna datoteka nije nađena</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pregledavanje slika</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Napusti cijeli zaslon</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži prečace</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Preglednik slika</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
